==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/ff-CM.pl <==
{
  am_pm_abbreviated => [
    "subaka",
    "kikii\N{U+0257}e"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "M",
    MEd => "MM-dd, E",
    MMM => "MMM",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMd => "d/MM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "ff-CM",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "aa\N{U+0253}",
    "maw",
    "nje",
    "naa",
    "mwd",
    "hbi",
    "dew"
  ],
  day_format_narrow => [
    "a",
    "m",
    "n",
    "n",
    "m",
    "h",
    "d"
  ],
  day_format_wide => [
    "aa\N{U+0253}nde",
    "mawbaare",
    "njeslaare",
    "naasaande",
    "mawnde",
    "hoore-biir",
    "dewo"
  ],
  day_stand_alone_abbreviated => [
    "aa\N{U+0253}",
    "maw",
    "nje",
    "naa",
    "mwd",
    "hbi",
    "dew"
  ],
  day_stand_alone_narrow => [
    "a",
    "m",
    "n",
    "n",
    "m",
    "h",
    "d"
  ],
  day_stand_alone_wide => [
    "aa\N{U+0253}nde",
    "mawbaare",
    "njeslaare",
    "naasaande",
    "mawnde",
    "hoore-biir",
    "dewo"
  ],
  era_abbreviated => [
    "H-I",
    "C-I"
  ],
  era_narrow => [
    "H-I",
    "C-I"
  ],
  era_wide => [
    "Hade Iisa",
    "Caggal Iisa"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Fulah",
  month_format_abbreviated => [
    "sii",
    "col",
    "mbo",
    "see",
    "duu",
    "kor",
    "mor",
    "juk",
    "slt",
    "yar",
    "jol",
    "bow"
  ],
  month_format_narrow => [
    "s",
    "c",
    "m",
    "s",
    "d",
    "k",
    "m",
    "j",
    "s",
    "y",
    "j",
    "b"
  ],
  month_format_wide => [
    "siilo",
    "colte",
    "mbooy",
    "see\N{U+0257}to",
    "duujal",
    "korse",
    "morso",
    "juko",
    "siilto",
    "yarkomaa",
    "jolal",
    "bowte"
  ],
  month_stand_alone_abbreviated => [
    "sii",
    "col",
    "mbo",
    "see",
    "duu",
    "kor",
    "mor",
    "juk",
    "slt",
    "yar",
    "jol",
    "bow"
  ],
  month_stand_alone_narrow => [
    "s",
    "c",
    "m",
    "s",
    "d",
    "k",
    "m",
    "j",
    "s",
    "y",
    "j",
    "b"
  ],
  month_stand_alone_wide => [
    "siilo",
    "colte",
    "mbooy",
    "see\N{U+0257}to",
    "duujal",
    "korse",
    "morso",
    "juko",
    "siilto",
    "yarkomaa",
    "jolal",
    "bowte"
  ],
  name => "Fulah Cameroon",
  native_language => "Pulaar",
  native_name => "Pulaar Kameruun",
  native_script => undef,
  native_territory => "Kameruun",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Termes 1",
    "Termes 2",
    "Termes 3",
    "Termes 4"
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Termes 1",
    "Termes 2",
    "Termes 3",
    "Termes 4"
  ],
  script => undef,
  territory => "Cameroon",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.19.tar.gz: DateTime-Locale-1.19/share/ff-CM.pl <==
{
  am_pm_abbreviated => [
    "subaka",
    "kikii\N{U+0257}e",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "M",
    MEd => "MM-dd, E",
    MMM => "MMM",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMd => "d/MM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ff-CM",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "aa\N{U+0253}",
    "maw",
    "nje",
    "naa",
    "mwd",
    "hbi",
    "dew",
  ],
  day_format_narrow => [
    "a",
    "m",
    "n",
    "n",
    "m",
    "h",
    "d",
  ],
  day_format_wide => [
    "aa\N{U+0253}nde",
    "mawbaare",
    "njeslaare",
    "naasaande",
    "mawnde",
    "hoore-biir",
    "dewo",
  ],
  day_stand_alone_abbreviated => [
    "aa\N{U+0253}",
    "maw",
    "nje",
    "naa",
    "mwd",
    "hbi",
    "dew",
  ],
  day_stand_alone_narrow => [
    "a",
    "m",
    "n",
    "n",
    "m",
    "h",
    "d",
  ],
  day_stand_alone_wide => [
    "aa\N{U+0253}nde",
    "mawbaare",
    "njeslaare",
    "naasaande",
    "mawnde",
    "hoore-biir",
    "dewo",
  ],
  era_abbreviated => [
    "H-I",
    "C-I",
  ],
  era_narrow => [
    "H-I",
    "C-I",
  ],
  era_wide => [
    "Hade Iisa",
    "Caggal Iisa",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Fulah",
  month_format_abbreviated => [
    "sii",
    "col",
    "mbo",
    "see",
    "duu",
    "kor",
    "mor",
    "juk",
    "slt",
    "yar",
    "jol",
    "bow",
  ],
  month_format_narrow => [
    "s",
    "c",
    "m",
    "s",
    "d",
    "k",
    "m",
    "j",
    "s",
    "y",
    "j",
    "b",
  ],
  month_format_wide => [
    "siilo",
    "colte",
    "mbooy",
    "see\N{U+0257}to",
    "duujal",
    "korse",
    "morso",
    "juko",
    "siilto",
    "yarkomaa",
    "jolal",
    "bowte",
  ],
  month_stand_alone_abbreviated => [
    "sii",
    "col",
    "mbo",
    "see",
    "duu",
    "kor",
    "mor",
    "juk",
    "slt",
    "yar",
    "jol",
    "bow",
  ],
  month_stand_alone_narrow => [
    "s",
    "c",
    "m",
    "s",
    "d",
    "k",
    "m",
    "j",
    "s",
    "y",
    "j",
    "b",
  ],
  month_stand_alone_wide => [
    "siilo",
    "colte",
    "mbooy",
    "see\N{U+0257}to",
    "duujal",
    "korse",
    "morso",
    "juko",
    "siilto",
    "yarkomaa",
    "jolal",
    "bowte",
  ],
  name => "Fulah Cameroon",
  native_language => "Pulaar",
  native_name => "Pulaar Kameruun",
  native_script => undef,
  native_territory => "Kameruun",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Termes 1",
    "Termes 2",
    "Termes 3",
    "Termes 4",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Termes 1",
    "Termes 2",
    "Termes 3",
    "Termes 4",
  ],
  script => undef,
  territory => "Cameroon",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 33,
}
